#   Nido, a Raspberry Pi-based home thermostat.
#
#   Copyright (C) 2016 Alex Marshall
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.
#   If not, see <http://www.gnu.org/licenses/>.


class NidoDaemonError(Exception):
    """Exception class for errors generated by the Nido daemon
    process.
    """

    def __init__(self, msg):
        self.msg = msg
        return

    def __str__(self):
        return repr(self.msg)


class DBError(NidoDaemonError):
    """Exception class for error generated by the database interface."""


class SchedulerClientError(NidoDaemonError):
    """Exception class for errors generated by the daemon scheduler RPC
    service.
    """


class ThermostatClientError(NidoDaemonError):
    """Exception class for errors generated by the daemon thermostat RPC
    service.
    """


class ControllerError(NidoDaemonError):
    """Exception class for errors generated by the hardware
    controller.
    """


class SensorError(NidoDaemonError):
    """Exception class for errors generated by the hardware
    sensor.
    """


class ThermostatError(NidoDaemonError):
    """Exception class for errors generated by the thermostat."""
